%%---10--|----20---|----30---|----40---|----50---|
-module(long_export).

-export([aaa/0,
         bbb/0,
         ccc/0,
         ddd/0,
         eee/0,
         fff/0]).
-export([ggg/0,
         hhh/0]).


aaa() ->
    ok.


bbb() ->
    ok.


ccc() ->
    ok.


ddd() ->
    ok.


eee() ->
    ok.


fff() ->
    ok.


ggg() ->
    ok.


hhh() ->
    ok.
